## Inputs

- `gold.inheight.input` input height of the measurements
- `gold.snobal.data.input.short` multiple years of input measurements
- `gold.snobal.data.input.short` one year of input measurements
- `gold.snobal.ppt.input` multiple years of precipitation
- `gold.snow.properties.input` initial snow conditions

## Outputs

- `gold.snobal.out` one year of snobal model results
- `gold.snobal.output.all` is all timesteps even sub data time step

## Model run

`run_snobal.sh` will run for one year
